@@ -19,7 +19,7 @@ class AioClientArgsCreator(ClientArgsCreator):
             service_model, client_config, endpoint_bridge, region_name,
             endpoint_url, is_secure, scoped_config)
 
-        # service_name = final_args['service_name']
+        service_name = final_args['service_name'] # noqa
         parameter_validation = final_args['parameter_validation']
         endpoint_config = final_args['endpoint_config']
         protocol = final_args['protocol']
@@ -59,6 +59,7 @@ class AioClientArgsCreator(ClientArgsCreator):
             timeout=(new_config.connect_timeout, new_config.read_timeout),
             socket_options=socket_options,
             client_cert=new_config.client_cert,
+            proxies_config=new_config.proxies_config,
             connector_args=new_config.connector_args)
 
         serializer = botocore.serialize.create_serializer(
